@@ -14,7 +14,7 @@ from hdx.utilities.typehint import ListTuple
 from hxl.input import InputOptions, munge_url
 from slugify import slugify
 
-from . import get_startend_dates_from_dataset_date, match_template
+from . import get_startend_dates_from_reference_period, match_template
 from .sources import Sources
 
 logger = logging.getLogger(__name__)
@@ -97,7 +97,7 @@ class Read(Retrieve):
         """
         if rate_limit:
             kwargs["rate_limit"] = rate_limit
-        custom_configs = dict()
+        custom_configs = {}
         hdx_auth = kwargs.get("hdx_auth")
         if hdx_auth:
             custom_configs["hdx"] = {"headers": {"Authorization": hdx_auth}}
@@ -336,7 +336,7 @@ class Read(Retrieve):
             if "source_date" not in datasetinfo:
                 datasetinfo[
                     "source_date"
-                ] = get_startend_dates_from_dataset_date(
+                ] = get_startend_dates_from_reference_period(
                     dataset, today=self.today
                 )
             if "source" not in datasetinfo:
@@ -346,18 +346,18 @@ class Read(Retrieve):
             Sources.standardise_datasetinfo_source_date(datasetinfo)
             return resource
         if "source_date" not in datasetinfo:
-            source_date = dict()
+            source_date = {}
         else:
             source_date = None
         if "source" not in datasetinfo:
-            source = dict()
+            source = {}
         else:
             source = None
         if "source_url" not in datasetinfo:
-            source_url = dict()
+            source_url = {}
         else:
             source_url = None
-        datasets = dict()
+        datasets = {}
         for hxltag, dataset_name in dataset_nameinfo.items():
             dataset = datasets.get(dataset_name)
             if not dataset:
@@ -368,7 +368,7 @@ class Read(Retrieve):
                     key = "default_date"
                 else:
                     key = hxltag
-                source_date[key] = get_startend_dates_from_dataset_date(
+                source_date[key] = get_startend_dates_from_reference_period(
                     dataset, today=self.today
                 )
             if source is not None:
