@@ -1,3 +1,4 @@
+from datetime import datetime
 from logging import Logger
 from typing import Dict, List, Optional, Union
 
@@ -12,31 +13,67 @@ class Sources:
     should_overwrite_sources = False
 
     @classmethod
-    def set_default_source_date_format(cls, format):
+    def set_default_source_date_format(cls, format: str) -> None:
+        """Set new default source date format. (Default is "%b %-d, %Y".)
+
+        Args:
+            format (str): Date format
+
+        Returns:
+            None
+        """
         cls.default_source_date_format = format
 
     @classmethod
-    def set_default_date_range_separator(cls, separator):
+    def set_default_date_range_separator(cls, separator: str) -> None:
+        """Set new default source date range separator. (Default is "-".)
+
+        Args:
+            separator (str): Separator
+
+        Returns:
+            None
+        """
         cls.default_date_range_separator = separator
 
     @classmethod
-    def set_should_overwrite_sources(cls, overwrite):
+    def set_should_overwrite_sources(cls, overwrite: bool) -> None:
+        """Set whether a source should overwrite a previous one with the same
+        HXL hashtag. (Default is to keep the previous source.)
+
+        Args:
+            overwrite (bool): Whether to overwrite previous source
+
+        Returns:
+            None
+        """
         cls.should_overwrite_sources = overwrite
 
     @staticmethod
-    def standardise_datasetinfo_source_date(datasetinfo):
+    def standardise_datasetinfo_source_date(
+        datasetinfo: Dict,
+    ) -> Optional[datetime]:
+        """Standardise source date format in datasetinfo dictionary. Returns
+        default end date or None.
+
+        Args:
+            datasetinfo (Dict): Information about dataset
+
+        Returns:
+            Optional[datetime]: Default end date or None
+        """
         source_date = datasetinfo.get("source_date")
         if not source_date:
             datasetinfo["source_date"] = None
             return None
 
-        output_source_date = dict()
+        output_source_date = {}
 
         def set_source_date(date, hxltag="default_date", startend="end"):
             if isinstance(date, str):
                 date = parse_date(date)
             if hxltag not in output_source_date:
-                output_source_date[hxltag] = dict()
+                output_source_date[hxltag] = {}
             output_source_date[hxltag][startend] = date
 
         if isinstance(source_date, dict):
@@ -63,7 +100,19 @@ class Sources:
         return None
 
     @classmethod
-    def get_hxltag_source_datetime(cls, datasetinfo, hxltag, fallback=False):
+    def get_hxltag_source_datetime(
+        cls, datasetinfo: Dict, hxltag: str, fallback: bool = False
+    ) -> datetime:
+        """Get standardised source date for HXL hashtag as datetime
+
+        Args:
+            datasetinfo (Dict): Information about dataset
+            hxltag (str): HXL hashtag to check
+            fallback (bool): Whether to fall back to default_date. Defaults to False.
+
+        Returns:
+            datetime: Standardised source date for HXL hashtag
+        """
         cls.standardise_datasetinfo_source_date(datasetinfo)
         source_date = datasetinfo["source_date"]
         date = source_date.get(hxltag)
@@ -74,7 +123,16 @@ class Sources:
         return date
 
     @classmethod
-    def format_hxltag_source_date(cls, datasetinfo, date):
+    def format_hxltag_source_date(cls, datasetinfo: Dict, date: Dict) -> str:
+        """Get formatted date from source date
+
+        Args:
+            datasetinfo (Dict): Information about dataset
+            date (Dict): Source date dictionary
+
+        Returns:
+            str: Formatted source date string
+        """
         source_date_format = datasetinfo.get(
             "source_date_format", cls.default_source_date_format
         )
@@ -98,7 +156,20 @@ class Sources:
         return enddate
 
     @classmethod
-    def get_hxltag_source_date(cls, datasetinfo, hxltag, fallback=False):
+    def get_hxltag_source_date(
+        cls, datasetinfo: Dict, hxltag: str, fallback: bool = False
+    ) -> str:
+        """Get standardised and formatted source date for HXL hashtag as
+        string
+
+        Args:
+            datasetinfo (Dict): Information about dataset
+            hxltag (str): HXL hashtag to check
+            fallback (bool): Whether to fall back to default_date. Defaults to False.
+
+        Returns:
+            str: Standardised and formatted source date for HXL hashtag
+        """
         date = cls.get_hxltag_source_datetime(datasetinfo, hxltag, fallback)
         if not date:
             return
@@ -112,7 +183,7 @@ class Sources:
         source: ListTuple[str],
         logger: Logger,
         should_overwrite_sources: Optional[bool] = None,
-    ):
+    ) -> None:
         """Add source to sources preventing duplication.
 
         Args:
@@ -149,7 +220,7 @@ class Sources:
         sources_to_add: List[ListTuple],
         logger: Logger,
         should_overwrite_sources: Optional[bool] = None,
-    ):
+    ) -> None:
         """Add source to sources preventing duplication
 
         Args:
@@ -176,14 +247,16 @@ class Sources:
         no_sources: bool = False,
         should_overwrite_sources: Optional[bool] = None,
     ) -> Optional[Dict]:
-        """Create source configuration. If none of the arguments are suppled, source
-        configuration is None. suffix_attribute is an attribute to add to the end of
-        source HXL hashtags. admin_sources defines whether the admin unit is added as an
-        attribute (eg. a country iso3 code like +AFG). admin_level defines one or more
-        AdminLevel objects that will be used to map admin pcodes to country iso3 codes. If
-        admin_level is defined, admin_sources is assumed to be True. Alternatively,
-        admin_mapping_dict can be supplied to define mapping from amin names to attribute
-        suffixes. If no sources should be outputted no_sources should be set to True.
+        """Create source configuration. If none of the arguments are supplied,
+        source configuration is None. suffix_attribute is an attribute to add
+        to the end of source HXL hashtags. admin_sources defines whether the
+        admin unit is added as an attribute (eg. a country iso3 code like
+        +AFG). admin_level defines one or more AdminLevel objects that will be
+        used to map admin pcodes to country iso3 codes. If admin_level is
+        defined, admin_sources is assumed to be True. Alternatively,
+        admin_mapping_dict can be supplied to define mapping from amin names to
+        attribute suffixes. If no sources should be outputted no_sources should
+        be set to True.
 
         Args:
             suffix_attribute (Optional[str]): Suffix to add. Defaults to None.
@@ -196,7 +269,7 @@ class Sources:
         Returns:
              Optional[Dict]: Source configuration dictionary
         """
-        source_configuration = dict()
+        source_configuration = {}
         if no_sources:
             source_configuration["no_sources"] = True
             return source_configuration
@@ -211,7 +284,7 @@ class Sources:
             if isinstance(adminlevel, AdminLevel):
                 admin_mapping = adminlevel.pcode_to_iso3
             else:
-                admin_mapping = dict()
+                admin_mapping = {}
                 for admlevel in adminlevel:
                     admin_mapping.update(admlevel.pcode_to_iso3)
         elif admin_mapping_dict:
